@@ -5,7 +5,7 @@ import sys
 
 
 from .age import AgeCategory, EstimatedAge
-from .context import Context
+from .context import BodyPosition, CompassBearing, Context, Present
 from .individual import AgeSexStature, BurialInfo, Individual, LongBoneMeasurement, OsteologicalSex
 from .joints import JointCondition, Joints
 from .left_right import LeftRight
@@ -21,8 +21,10 @@ if sys.version_info < (3, 7):
 
 
 __title__ = 'bioarch'
-__version__ = '0.0.15'
+__version__ = '0.0.34'
 __author__ = 'Guy Taylor'
 
-__all__ = ['AgeCategory', 'EstimatedAge'] + ['Context'] + ['AgeSexStature', 'BurialInfo', 'Individual', 'LongBoneMeasurement', 'OsteologicalSex'] + \
-          ['JointCondition', 'Joints'] + ['EnthesialMarker', 'OccupationalMarkers'] + ['LeftRight'] + ['Mouth', 'Tooth'] + ['Sex'] + ['Trauma', 'TraumaCategory']
+__all__ = ['AgeCategory', 'EstimatedAge'] + ['BodyPosition', 'CompassBearing', 'Context', 'Present'] + \
+          ['AgeSexStature', 'BurialInfo', 'Individual', 'LongBoneMeasurement', 'OsteologicalSex'] + \
+          ['JointCondition', 'Joints'] + ['EnthesialMarker', 'OccupationalMarkers'] + ['LeftRight'] + \
+          ['Mouth', 'Tooth'] + ['Sex'] + ['Trauma', 'TraumaCategory']
